/*
 *	sgtty.h	1.1
 */

#ifndef _SGTTY_
#define _SGTTY_

/*
 * Structure for stty and gtty system calls.
 */

struct sgttyb {
	char	sg_ispeed;		/* input speed */
	char	sg_ospeed;		/* output speed */
	char	sg_erase;		/* erase character */
	char	sg_kill;		/* kill character */
	short	sg_flags;		/* mode flags */
};

#define	stty(fd, arg)	ioctl(fd, TIOCSETP, arg)
#define	gtty(fd, arg)	ioctl(fd, TIOCGETP, arg)

/*
 * List of special characters
 */

struct tchars {
	char	t_intrc;	/* interrupt */
	char	t_quitc;	/* quit */
	char	t_startc;	/* start output */
	char	t_stopc;	/* stop output */
	char	t_eofc;		/* end-of-file */
	char	t_brkc;		/* input delimiter (like nl) */
};

/*
 * Modes
 */

#define	TANDEM   0000001
#define	CBREAK   0000002
#define	LCASE    0000004
#define	ECHO     0000010
#define	CRMOD    0000020
#define	RAW      0000040
#define	ODDP     0000100
#define	EVENP    0000200
#define ANYP     0000300
#define	NLDELAY  0001400
#define	TBDELAY  0006000
#define	XTABS    0006000
#define	CRDELAY  0030000
#define	VTDELAY  0040000
#define BSDELAY  0100000
#define ALLDELAY 0177400

/*
 * Delay algorithms
 */

#define	CR0	0
#define	CR1	010000
#define	CR2	020000
#define	CR3	030000
#define	NL0	0
#define	NL1	000400
#define	NL2	001000
#define	NL3	001400
#define	TAB0	0
#define	TAB1	002000
#define	TAB2	004000
/*#define	NOAL	004000*/
#define	FF0	0
#define	FF1	040000
#define	BS0	0
#define	BS1	0100000

/*
 * Speeds
 */

#define B0	0
#define B50	1
#define B75	2
#define B110	3
#define B134	4
#define B150	5
#define B200	6
#define B300	7
#define B600	8
#define B1200	9
#define	B1800	10
#define B2400	11
#define B4800	12
#define B9600	13
#define	B19200	14
#define	B38400	15
#define	EXTA	14
#define	EXTB	15

/*
 *	ioctl arguments
 */

#ifndef fIOC
# define fIOC      ('f'<<8)
# define FIOCLEX   (fIOC|1)
# define FIONCLEX  (fIOC|2)
#endif fIOC

#ifndef tIOC
# define tIOC      ('t'<<8)
# define TIOCGETD  (tIOC|0)
# define TIOCSETD  (tIOC|1)
# define TIOCHPCL  (tIOC|2)
# define TIOCGETP  (tIOC|8)
# define TIOCSETP  (tIOC|9)
# define TIOCSETN  (tIOC|10)
# define TIOCEXCL  (tIOC|13)
# define TIOCNXCL  (tIOC|14)
# define TIOCFLUSH (tIOC|16)
# define TIOCSETC  (tIOC|17)
# define TIOCGETC  (tIOC|18)
#endif tIOC

#endif _SGTTY_
