/*
 *	unistd.h
 */

/*
 * This file defines the symbolic constants and structures which are
 * referenced in the "/usr/group" standard and which are not already
 * defined or declared in some other "include" file.
 */

#ifndef _UNISTD_
#define _UNISTD_

/*
 *	Symbolic constants for the "access" function
 */

#ifndef R_OK
# define R_OK	4	/* Test for "Read" permission */
# define W_OK	2	/* Test for "Write" permission */
# define X_OK	1	/* Test for "Execute" (Search) Permission */
# define F_OK	0	/* Test for existence of file */
#endif

/*
 *	Symbolic constants for the "lockf" function
 */

#define F_ULOCK	0	/* Unlock a previously locked region */
#define F_LOCK	1	/* Lock a region for exclusive use */
#define F_TLOCK	2	/* Test and lock a region for exclusive use */
#define F_TEST	3	/* Test a region for a previous lock */

/*
 *	Symbolic constants for the "lseek" function
 */

#define SEEK_SET	0	/* Set file pointer to "offset" */
#define SEEK_CUR	1	/* Set file pointer to current plus "offset" */
#define SEEK_END	2	/* Set file pointer to EOF plus "offset" */
#ifndef L_SET
# define L_SET		0	/* Set file pointer to "offset" */
# define L_INCR		1	/* Set file pointer to current plus "offset" */
# define L_XTND		2	/* Set file pointer to EOF plus "offset" */
#endif

/*
 *	Path names of the passwd file and group file
 */

#define GF_PATH	"/etc/group"	/* Path name for the "group" file */
#define PF_PATH	"/etc/passwd"	/* Path name for the "passwd" file */
#define IN_PATH	"/usr/include"	/* Path name for <...> files */

/*
 *	Structure for "utime" function
 */

struct utimbuf {
	time_t	actime;		/* Date and time of last access */
	time_t	modtime;	/* Date and time of last modification */
};

#endif _UNISTD_
